
# THIS FILE IS GENERATED FROM wofry SETUP.PY
short_version = '1.0.27'
version = '1.0.27'
full_version = '1.0.27'
git_revision = 'd65c31e06b2d1c2dcc09921b302d8348ad740692'
release = True

if not release:
    version = full_version
    short_version += ".dev"
